@@ -1,6 +1,6 @@
 """A friendly Python Utilitary RPA."""
 
-__version__ = "1.18"
+__version__ = "1.19"
 __author__ = "Jonathan Bolo"
 
 import os, re, shutil
@@ -453,7 +453,7 @@ def create_folder_env(dir_path):
     
     return
 
-def config_logging(file_log="", level=logging.DEBUG, console=True):
+def config_logging(file_log=None, level=logging.DEBUG, console=True):
     '''
     Funcion que configura la gestion de Logs
     '''
@@ -461,7 +461,7 @@ def config_logging(file_log="", level=logging.DEBUG, console=True):
     formatter = logging.Formatter('%(asctime)-5s %(filename)s %(lineno)d %(levelname)-8s %(message)s')
     
     #logging file
-    if file_log != "":
+    if file_log and file_log != "":
         fh = logging.FileHandler(file_log)
         fh.setFormatter(formatter)
         
@@ -471,7 +471,7 @@ def config_logging(file_log="", level=logging.DEBUG, console=True):
     
     log=logging.getLogger(__name__)
     
-    if file_log:
+    if file_log and file_log != "":
         log.addHandler(fh)
     
     if console:
